import { EventFragment } from "@/gql/graphql";
import { isTodayOrFuture, formatDate } from "@/lib/date";
import { parse } from "date-fns";
import {
  getSingularEvents,
  organizeEventsByDate,
  sortSingularEvents,
} from "@/lib/event";
import Link from "next/link";
import { EventItem } from "./EventItem";
import styles from "./upcomingEvents.module.scss";

export const UpcomingEvents = ({ events }: { events: EventFragment[] }) => {
  const upcomingSingularEvents = sortSingularEvents(
    getSingularEvents(events).filter((event) =>
      isTodayOrFuture(event.occurrence.start)
    )
  );
  const sliced = upcomingSingularEvents.slice(0, 10);
  const eventsByDate = organizeEventsByDate(sliced);

  return (
    <section className={styles.upcomingWrapper}>
      <h2 className="circlehead">
        <span className="circle"></span>
        <span className="circle"></span>
        <span className="circle"></span>
        Denne uka på Chateau Neuf
      </h2>
      <div className={styles.eventList}>
        {Object.keys(eventsByDate).map((day) => {
          const eventsThisDay = eventsByDate[day];
          return (
            <div key={day}>
              <h3>
                {formatDate(
                  parse(day, "yyyy-MM-dd", new Date()),
                  "eeee dd.MM."
                )}
              </h3>
              <ul>
                {eventsThisDay.map((event) => (
                  <EventItem
                    key={`${event.id}-${event.occurrence.id}`}
                    event={event}
                    mode="singular-time-only"
                    size="medium"
                  />
                ))}
              </ul>
            </div>
          );
        })}
      </div>
      <div className={styles.calendarLink}>
        <Link href="/arrangementer?mode=calendar">Vis kalender &rarr;</Link>
      </div>
    </section>
  );
};
